@@ -13,3 +13,7 @@ datawizard::unstandardize
 #' @importFrom insight print_md
 #' @export
 insight::print_md
+
+#' @importFrom insight print_html
+#' @export
+insight::print_html
