@@ -75,7 +75,7 @@
     facet_by <- NULL
     if (insight::n_unique(data$Parameter) > 1) {
       facet_by <- c(facet_by, "Parameter")
-      aes$color <- "Parameter"
+      # aes$color <- "Parameter"
     }
     if (insight::n_unique(data$Group) > 1) {
       facet_by <- c(facet_by, "Group")
@@ -176,8 +176,12 @@
   # axis and legend labels
   # ------------------------------------------------------------------------
   if (!is.null(model_data) && !is.null(model_response)) {
-    # response - mapped to the y-axis
-    ylab <- .safe(attr(model_data[[model_response]], "label", exact = TRUE))
+    if ("estimate_slopes" %in% att$class) {
+      ylab <- att$trend
+    } else {
+      # response - mapped to the y-axis if not slopes
+      ylab <- .safe(attr(model_data[[model_response]], "label", exact = TRUE))
+    }
     # fix default y-label, if necessary
     y_prefix <- aes$y
     if (y_prefix == "Predicted") {
@@ -264,7 +268,7 @@
   if (isTRUE(model_info$is_linear) && !isTRUE(transform)) {
     # add information about response transformation
     trans_fun <- .safe(insight::find_transformation(attributes(x)$model))
-    if (!is.null(trans_fun) && trans_fun != "identity") {
+    if (!is.null(trans_fun) && all(trans_fun != "identity")) {
       show_data <- FALSE
     }
   }
@@ -454,7 +458,7 @@
   # Default changes for binomial models
   shape <- 16
   stroke <- 0
-  if (insight::model_info(model)$is_binomial) {
+  if (insight::model_info(model, response = 1)$is_binomial) {
     shape <- "|"
     stroke <- 1
   }
