@@ -14,6 +14,13 @@ test_that("estimate_means() - counterfactuals", {
   expect_snapshot(print(estimate_means(m, "spp", backend = "marginaleffects"), zap_small = TRUE, table_width = Inf), variant = "windows") # nolint
   expect_snapshot(print(estimate_means(m, "spp", backend = "marginaleffects", estimate = "population"), zap_small = TRUE, table_width = Inf), variant = "windows") # nolint
 
+  expect_snapshot(print(estimate_means(m, "spp", backend = "marginaleffects", predict = "inverse_link"), zap_small = TRUE, table_width = Inf), variant = "windows") # nolint
+  expect_snapshot(print(estimate_means(m, "spp", backend = "marginaleffects", estimate = "population", predict = "inverse_link"), zap_small = TRUE, table_width = Inf), variant = "windows") # nolint
+
+  out1 <- estimate_means(m, "spp", backend = "marginaleffects", predict = "inverse_link")
+  out2 <- estimate_means(m, "spp", backend = "emmeans")
+  expect_equal(out1$Mean, out2$Rate, tolerance = 1e-1)
+
   data(sleepstudy, package = "lme4")
   # create imbalanced data set
   set.seed(123)
